pitchtools.iterate_named_chromatic_pitch_pairs_in_expr
======================================================

.. autofunction:: abjad.tools.pitchtools.iterate_named_chromatic_pitch_pairs_in_expr.iterate_named_chromatic_pitch_pairs_in_expr
   :noindex:
